@@ -1,26 +1,8 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-   Copyright 2015 Franck Arrecot <franck.arrecot@gmail.com>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+   SPDX-FileCopyrightText: 2015 Franck Arrecot <franck.arrecot@gmail.com>
+   * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+   */
 
 
 #include "quickselectdialog.h"
@@ -30,25 +12,25 @@
 #include <QHeaderView>
 #include <QKeyEvent>
 #include <QLabel>
+#include <QSortFilterProxyModel>
 #include <QTreeView>
 #include <QVBoxLayout>
 
 #include <KLocalizedString>
-#include <KRecursiveFilterProxyModel>
 
 using namespace Widgets;
 
 QuickSelectDialog::QuickSelectDialog(QWidget *parent)
     : QDialog(parent),
       m_model(nullptr),
-      m_filterProxyModel(new KRecursiveFilterProxyModel(this)),
+      m_filterProxyModel(new QSortFilterProxyModel(this)),
       m_label(new QLabel(this)),
       m_tree(new QTreeView(this))
 {
     setWindowTitle(i18n("Quick Select Dialog"));
 
     m_label->setText(i18n("You can start typing to filter the list of available pages"));
-    m_filterProxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+    m_filterProxyModel->setRecursiveFilteringEnabled(true);
 
     m_tree->setModel(m_filterProxyModel);
     m_tree->setObjectName(QStringLiteral("pagesView"));
@@ -89,7 +71,7 @@ void QuickSelectDialog::applyFilterChanged(const QString &textFilter)
     else
         m_label->setText(i18n("Path: %1", textFilter));
 
-    m_filterProxyModel->setFilterFixedString(textFilter);
+    m_filterProxyModel->setFilterRegularExpression(QRegularExpression(textFilter, QRegularExpression::CaseInsensitiveOption));
     m_tree->expandAll();
 }
 
@@ -97,7 +79,7 @@ bool QuickSelectDialog::eventFilter(QObject *, QEvent *ev)
 {
     if (ev->type() == QEvent::KeyPress) {
         auto event = static_cast<QKeyEvent*>(ev);
-        auto filter = m_filterProxyModel->filterRegExp().pattern();
+        auto filter = m_filterProxyModel->filterRegularExpression().pattern();
 
         switch (event->key()) {
         case Qt::Key_Backspace:
@@ -107,7 +89,7 @@ bool QuickSelectDialog::eventFilter(QObject *, QEvent *ev)
             filter = QString();
             break;
         default:
-            if (event->text().contains(QRegExp("^(\\w| )+$"))) {
+            if (event->text().contains(QRegularExpression(QStringLiteral("^(\\w| )+$")))) {
                 filter += event->text();
             }
             break;
