@@ -12,7 +12,13 @@
 
 #include "domain/taskrepository.h"
 
-class ZanshinRunner : public Plasma::AbstractRunner
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+using namespace Plasma;
+#else
+using namespace KRunner;
+#endif
+
+class ZanshinRunner : public AbstractRunner
 {
     Q_OBJECT
 
@@ -20,12 +26,12 @@ public:
     ZanshinRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~ZanshinRunner();
 
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
 private:
+    void match(RunnerContext &context) override;
+    void run(const RunnerContext &context, const QueryMatch &action) override;
+
     Domain::TaskRepository::Ptr m_taskRepository;
     const QString m_triggerWord;
 };
 
-
 #endif
