@@ -6,8 +6,8 @@
 
 #include <testlib/qtest_zanshin.h>
 
-#include <AkonadiCore/Akonadi/Collection>
-#include <AkonadiCore/Akonadi/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include "utils/mockobject.h"
 
